@@ -242,54 +242,7 @@
 #' Entin, J.K., Walker, J.P., Lohmann, D., and Toll, D. (2004), The Global
 #' Land Data Assimilation System, Bull. Amer. Meteor. Soc., 85(3), 381-394.
 #' 
-#' @examples
-#' # This is a sample data to run VIC.
-#' data(STEHE)
-#'
-#' forcing <- STEHE$forcing
-#' soil <- STEHE$soil
-#' veg <- STEHE$veg
-#'
-#' # Set the global options for a 7-days run.
-#' vic_param('start_year', 1949)
-#' vic_param('start_month', 1)
-#' vic_param('start_day', 1)
-#' vic_param('end_year', 1949)
-#' vic_param('end_month', 1)
-#' vic_param('end_day', 7)
-#' vic_param('step_per_day', 24)
-#' vic_param('snow_step_per_day', 24)
-#' vic_param('runoff_step_per_day', 24)
-#'
-#' # Run VIC.
-#' outputs <- vic(forcing, soil, veg)
-#' print(outputs)
-#'
-#' # Use user defind outputs and snowband parameters.
-#' vic_param('nbands', 5)
-#' band <- STEHE$snowbands
-#'
-#' out_info <- list(
-#'   wb = list(timescale = 'hour', aggpar = 6,
-#'             outvars = c('OUT_RUNOFF', 'OUT_BASEFLOW', 'OUT_SOIL_MOIST'),
-#'             aggtypes = c('sum', 'sum', 'end')),
-#'   eb = list(timescale = 'day', aggpar = 1,
-#'             outvars = c('OUT_SWE', 'OUT_SOIL_TEMP'),
-#'             aggtypes = c('avg', 'min'))
-#' )
-#'
-#' outputs <- vic(forcing, soil, veg, snowband = band, output_info = out_info)
-#' print(outputs)
-#'
-#' # Example of parallelization
-#' \dontrun{
-#' library(doParallel)
-#' registerDoParallel(cores=4)
-#' outputs <- vic(forcing, soil, veg, snowband = band, parall = TRUE)
-#' stopImplicitCluster()
-#' print(outputs)
-#' }
-#' 
+#' @example R/examples/ex-VIC5.R
 #' @export
 vic <- function(forcing, soil, veg,
                 output_info = NULL,
@@ -344,15 +297,12 @@ vic <- function(forcing, soil, veg,
       stop(sprintf('Length of forcing data "%s" (%d) is too short for model require (%d).',
                    ft, fl, minfl))
     }
-
     fc <- ncol(forcing[[ft]])
     if(is.null(fc) && ncell > 1 || fc < ncell)
       stop(sprintf('Columns of forcing data "%s" (%d) are too few for model require. It should no less than number of gridcells (%d).', ft, fc, ncell))
   }
 
-
-  if(!is.list(veg))
-    veg <- list(veg)
+  if(!is.list(veg)) veg <- list(veg)
 
   if(is.vector(lake)) {
     lake <- t(lake)
@@ -371,13 +321,10 @@ vic <- function(forcing, soil, veg,
 
   forc_lack <- forc_types[!(forc_types %in% names(forcing))]
   celev <- getOption('VIC_global_params')[['nlayers']]*4+10
-  if("LW" %in% forc_lack)
-    J <- get_J()
-
-  if(ncell == 1) {
-    forcing <- data.frame(forcing[forc_types])
-  }
+  if("LW" %in% forc_lack) J <- get_J()
 
+  if(ncell == 1) forcing <- data.frame(forcing[forc_types])
+  
   globalopt <- getOption('VIC_global_params')
   `%dof%` <- ifelse(parall, foreach::`%dopar%`, foreach::`%do%`)
 
